===============================================================
Behavioral Observation Research Interactive Software (BORIS)
===============================================================

BORIS is an easy-to-use event logging software for video/audio coding or live observations.

BORIS is a free and open-source software available for GNU/Linux, Windows and MacOS.

It provides also some analysis tools like time budget.

The BORIS paper has more than `900 citations in scientific publications <http://www.boris.unito.it/pages/citations.html>`_ with peer-reviewing.

See http://www.boris.unito.it

..
    .. image:: https://img.shields.io/pypi/l/boris_behav_obs   :alt: PyPI - License

    .. image:: https://img.shields.io/pypi/l/boris-behav-obs   :alt: PyPI - License

.. image:: https://static.pepy.tech/personalized-badge/boris-behav-obs?period=total&units=international_system&left_color=black&right_color=orange&left_text=Downloads
 :target: https://pepy.tech/project/boris-behav-obs


Documentation
-------------------------------------

The official documentation is hosted here:
http://boris.readthedocs.io/

The documentation provides a good starting point for learning how to use BORIS.

Some video tutorials are available:
https://www.youtube.com/channel/UCo-Jyvzawwp0bRMEor4aLVQ


Bug reports and feature requests
--------------------------------------

To search for bugs, report them or request a feature, please use the github tracker:
https://github.com/olivierfriard/BORIS/issues

Citing BORIS
--------------------------------------

Please acknowledge and cite the use of this software and its authors when
results are used in publications or published elsewhere. You can use the
following BibTex entry

::

    @article {MEE3:MEE312584,
    author = {Friard, Olivier and Gamba, Marco},
    title = {BORIS: a free, versatile open-source event-logging software for video/audio coding and live observations},
    journal = {Methods in Ecology and Evolution},
    issn = {2041-210X},
    url = {http://dx.doi.org/10.1111/2041-210X.12584},
    doi = {10.1111/2041-210X.12584},
    pages = {n/a--n/a},
    keywords = {behavioural analysis, behaviour coding, coding scheme, ethology, observational data, ttime-budget},
    year = {2016},
    }

Licence
-----------------------------

Distributed with a `GPL v.3 license <LICENSE.TXT>`_::

Copyright (C) 2012-2022 Olivier Friard




